==> mercury-0.1.6.tar.gz: lib/src/models/message.dart <==
part of mercury;

/// Represents a message sent to a channel by a user or bot.
class Message extends EntityBase {
  /// The channel that this message was sent in.
  GuildTextChannel channel = null;

  /// The author of this message.
  User author = null;

  /// Content of this message.
  String content = '';

  /// Whether this message was a TTS message (Text-To-Speech)
  bool isTTS = false;

  /// Whether this message mentioned everyone
  bool mentionsEveryone = false;

  /// List of users who have been mentioned
  List<User> mentions = [];

  /// Whether this message has been pinned
  bool pinned = false;

  /// The type of message. You can use [MessageTypeHelper] to help with this.
  int type = 0;

  @override
  Future _update(Map<String, dynamic> json) async {
    await super._update(json);
    content = json['content'] ?? content;
    isTTS = json['tts'] ?? isTTS;
    mentionsEveryone = json['mention_everyone'] ?? mentionsEveryone;

    if (json['author'] != null) {
      if (session.users.containsId(json['author']['id']))
        author = session.users.get(json['author']['id']).value;
      else {
        var authorModel = new User(session);
        await authorModel._update(json['author']);
        session.users.set(authorModel);
        author = authorModel;
      }
    }

    channel = session.getChannel(json['channel_id']).value;

    // I should probably make this not as ugly
    if (json['mentions'] != null) {
      var mentions0 = new List.from(json['mentions']);
      await Future.forEach(mentions0, (mention1) async {
        if (session.users.containsId(mention1['id'])) {
          mentions.add(session.users.get(mention1['id']).value);
        } else {
          var mentionResponse = await session._rest
              .executeRoute(ApiEndpoints.users.getUserWithId(mention1['id']));
          var mentionModel = new User(session);
          await mentionModel._update(mentionResponse.json);
          session.users.set(mentionModel);
          mentions.add(mentionModel);
        }
      });
    }
    type = json['type'] ?? type;
    channel.messages.set(this);
  }

  /// Delete a message.
  ///
  /// Fires a Message Delete event on the client.
  Future delete({RequestOptions options}) async {
    var resp = await session._rest
        .executeRoute(ApiEndpoints.channels.deleteMessage(channel.id, id));
  }

  /// Edits this message.
  ///
  /// Returns null if the client doesn't have sufficient permissions.
  /// Fires a Message Update event on the client.
  Future edit(MessageUpdateProperties props, {RequestOptions options}) async {
    await session._rest.executeRoute(
        ApiEndpoints.channels.editMessage(channel.id, id),
        jsonParams: props.build({}, session));
  }

  Message(Session client) : super(client);
}

==> mercury-0.2.0.tar.gz: lib/src/models/message.dart <==
part of mercury;

/// Represents a message sent to a channel by a user or bot.
class Message extends EntityBase {
  /// The channel that this message was sent in.
  GuildTextChannel channel = null;

  /// The author of this message.
  User author = null;

  /// Content of this message.
  String content = '';

  /// Whether this message was a TTS message (Text-To-Speech)
  bool isTTS = false;

  /// Whether this message mentioned everyone
  bool mentionsEveryone = false;

  /// List of users who have been mentioned
  List<User> mentions = [];

  /// Whether this message has been pinned
  bool pinned = false;

  /// The type of message. You can use [MessageTypeHelper] to help with this.
  int type = 0;

  @override
  Future _update(Map<String, dynamic> json) async {
    await super._update(json);
    content = json['content'] ?? content;
    isTTS = json['tts'] ?? isTTS;
    mentionsEveryone = json['mention_everyone'] ?? mentionsEveryone;

    if (json['author'] != null) {
      if (session.users.containsId(json['author']['id']))
        author = session.users.get(json['author']['id']).value;
      else {
        var authorModel = new User(session);
        await authorModel._update(json['author']);
        session.users.set(authorModel);
        author = authorModel;
      }
    }

    channel = session.getCachedChannel(json['channel_id']).value;

    // I should probably make this not as ugly
    if (json['mentions'] != null) {
      var mentions0 = new List.from(json['mentions']);
      await Future.forEach(mentions0, (mention1) async {
        if (session.users.containsId(mention1['id'])) {
          mentions.add(session.users.get(mention1['id']).value);
        } else {
          var mentionResponse = await session._rest
              .executeRoute(ApiEndpoints.users.getUserWithId(mention1['id']));
          var mentionModel = new User(session);
          await mentionModel._update(mentionResponse.json);
          session.users.set(mentionModel);
          mentions.add(mentionModel);
        }
      });
    }
    type = json['type'] ?? type;
    channel.messages.set(this);
  }

  /// Delete a message.
  ///
  /// Fires a Message Delete event on the client.
  Future delete({RequestOptions options}) async {
    var resp = await session._rest
        .executeRoute(ApiEndpoints.channels.deleteMessage(channel.id, id));
  }

  /// Edits this message.
  ///
  /// Returns null if the client doesn't have sufficient permissions.
  /// Fires a Message Update event on the client.
  Future edit(MessageUpdateProperties props, {RequestOptions options}) async {
    await session._rest.executeRoute(
        ApiEndpoints.channels.editMessage(channel.id, id),
        jsonParams: props.build({}, session));
  }

  Message(Session client) : super(client);
}
